var GridMenu = {
	data: null,
	length: 0,
	rows: 0,
	visibleRows: 0,
	visibleCols: 0,
	centerRow: 0,
	selected: 0,
	container: null,
	debugMode: false
};

GridMenu.log = function(m) {
	if (this.debugMode) {
		debug.log("GridMenu.js - " + m);
	} 
};

GridMenu.error = function(m) {
	debug.log("GridMenu.js - " + m);
};

GridMenu.init = function() {
	this.data = $data;
	this.length = this.data.length;
	
	this.visibleRows = 2;
	this.visibleCols = 2;
	
	this.rows = Math.ceil((0.0 + this.length) / this.visibleCols);
	
	this.centerRow = Math.floor((this.visibleRows - 1) / 2);

	this.container = $('<div>').attr('id','gridmenu');
	this.container.appendTo($('#scenecontent'));
	
	alert('TOTALE: ROW: ' + this.rows);
	
	if (this.length > this.visibleRows * this.visibleCols) {
		$('#gridmenuscrollbar').show();
		$('#gridmenuscrollbar').sfScroll({
			pages:this.rows
		});	
	} else {
		$('#gridmenuscrollbar').hide();
	}
	this.showMenu();
	return;
};

GridMenu.draw = function() {
	this.container.empty();
	
	var currentRow = Math.floor(this.selected/this.visibleCols);
	
	var firstRow;
	if (currentRow <= this.centerRow) { 
		firstRow = 0;
	} else if (currentRow >= this.rows - (this.visibleRows - this.centerRow - 1)) {
		firstRow = parseInt(this.rows - this.visibleRows,10);
	} else {
		firstRow = parseInt(currentRow - this.centerRow,10);
	}
	
	for (var i=0; i<(this.visibleRows * this.visibleCols); i++) {
		var ci = i + (firstRow * this.visibleCols);
		
		if (ci < this.length) {
			this.container.append(GridMenu.createItem(this.data[ci],ci));
		}
		
	}

	if (this.data[this.selected]['streaming_url'] !== null) {
		$('#gridmenuhelpbar').sfKeyHelp({
			'enter': "Riproduci",
			'move': "Scegli il canale",
			'return':'Esci'
		});		
	} else {
		$('#gridmenuhelpbar').sfKeyHelp({
			'enter': "Lista Episodi",
			'move': "Scegli il canale",
			'return':'Esci'
		});
	}

	if (this.length > this.visibleRows * this.visibleCols) {
		$('#gridmenuscrollbar').sfScroll('move',currentRow);
	}

	this.focus();
};

GridMenu.createItem = function(obj,index) {

	  var html = '';
	  html += "<div class='element' id='element_"+index+"'>";
	  html += "<div class='hover'><img src='images/"+$resolution+"/gridmenuhover.png' width='100%' height='100%' /></div>";
	  html += "<div class='image'><img src='" + obj.icon + "' /></div>";
	  html += "</div>";

	  return html;
};

GridMenu.getObject = function(id) {
	return this.data[id];
};

GridMenu.showMenu = function() {
	this.log("SHOW MENU");
	this.draw();
};

GridMenu.unfocus = function() {
  $('#element_' + this.selected).removeClass('selected');
};

GridMenu.focus = function() {
	$('#element_' + this.selected).addClass('selected');
};

GridMenu.onEnter = function() {
	var obj = this.getObject(this.selected);
	
	//alert("------------------------------------- " + obj.episodes.length);
	if (obj.streaming_url !== null) {
		alert("________________________ PLAY STREAMING URL: " + obj.streaming_url);
		
		$playlist = {
			url: obj.streaming_url,
			title: obj.title
		};		
		
		$returnscene = "Scene1";
		
		sf.scene.hide('Scene1');
		sf.scene.show('player');
		sf.scene.focus('player');
	} else if (obj.episodes !== null && obj.episodes.length > 0) {
		$selectedShow = obj;
		
		$returnscene = "Scene1";
		$selectedEpisode = 0;
		sf.scene.hide('Scene1');
		sf.scene.show('Episodes');
		sf.scene.focus('Episodes');
	} else if (obj.episodes.length === 0) {
		alert("No episodes");
		$('#popupNoContent').sfPopup({
			text: 'Il canale selezionato non contiene video al momento.',
			buttons: 'OK'
		});
		$('#popupNoContent').sfPopup('show');			
	}
};

GridMenu.onRight = function() {
	
	if (this.selected < this.length-1) {
		this.unfocus();
		this.selected++;
		this.focus();
	}
	
	this.draw();
};

GridMenu.onLeft = function() {
	
	if (this.selected > 0) {
		this.unfocus();
		this.selected--;
		this.focus();
	}
	
	this.draw();
};

GridMenu.onDown = function() {
	var newSelected = this.selected + this.visibleCols;
	
	this.unfocus();
	if (newSelected < this.length) {
		this.selected = newSelected;
	} else {
		this.selected = this.length-1;
	}
	this.focus();
	
	this.draw();
};

GridMenu.onUp = function() {
	var newSelected = this.selected - this.visibleCols;
	
	if (newSelected >= 0) {
		this.unfocus();
		this.selected = newSelected;
		this.focus();
	}	
	
	this.draw();
};

GridMenu.onFocus = function() { 
	GridMenu.log('============================================================================= FOCUS');
};

GridMenu.showMenu = function() {
	this.draw();
};